package
Version:
v1.0.0
Opens a new window with list of versions in this module.
Published: Jun 3, 2026
License: MIT
Opens a new window with license information.
Imports: 11
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Package lockfile provides owner-token based local file locking.
Configure sets package-level defaults for locks created by New.
Lock provides owner-token based file locking.
New creates a Lock for the given base path.
Acquire attempts to acquire the lock.
Release removes the lock only if this process still owns it.
type Options struct {
TimeoutEnvVar string
DetailedTimeoutError bool
WarnBelowMinTimeout bool
Stderr io.Writer
}
Options configures lock acquisition behavior.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.